summaryrefslogtreecommitdiffstats
path: root/telecomm/java/android
diff options
context:
space:
mode:
authorSantos Cordon <santoscordon@google.com>2014-02-18 20:56:59 -0800
committerEvan Charlton <evanc@google.com>2014-02-20 17:08:25 -0800
commit591ef664d85c1f6e3c8e6a2bf8d94b9e60fcabb7 (patch)
tree7ee7a610c3586042120b7ff00f61eab6a68d04e5 /telecomm/java/android
parentbd63f90a789bfb608dbd036d60c4d08f9fd1f2d9 (diff)
downloadframeworks_base-591ef664d85c1f6e3c8e6a2bf8d94b9e60fcabb7.zip
frameworks_base-591ef664d85c1f6e3c8e6a2bf8d94b9e60fcabb7.tar.gz
frameworks_base-591ef664d85c1f6e3c8e6a2bf8d94b9e60fcabb7.tar.bz2
Fix build.
Change-Id: I4633e4ab3753f0de328bbe0ef59e87dac1d58d54
Diffstat (limited to 'telecomm/java/android')
-rw-r--r--telecomm/java/android/telecomm/CallServiceSelector.java15
1 files changed, 8 insertions, 7 deletions
diff --git a/telecomm/java/android/telecomm/CallServiceSelector.java b/telecomm/java/android/telecomm/CallServiceSelector.java
index cfa8eb3..74f05fe 100644
--- a/telecomm/java/android/telecomm/CallServiceSelector.java
+++ b/telecomm/java/android/telecomm/CallServiceSelector.java
@@ -49,13 +49,13 @@ public abstract class CallServiceSelector extends Service {
}
@Override
- public void select(CallInfo callInfo, List<String> callServiceIds,
+ public void select(CallInfo callInfo, List<CallServiceInfo> callServiceInfos,
ICallServiceSelectionResponse response) throws RemoteException {
// Ensure that we're running with the app's normal permission level
long ident = Binder.clearCallingIdentity();
try {
- response.setSelectedCallServiceIds(
- CallServiceSelector.this.select(callInfo, callServiceIds));
+ response.setSelectedCallServiceInfos(
+ CallServiceSelector.this.select(callInfo, callServiceInfos));
} finally {
Binder.restoreCallingIdentity(ident);
}
@@ -91,9 +91,10 @@ public abstract class CallServiceSelector extends Service {
* This method is not called on the UI thread and is safe to block.
*
* @param callInfo The call being placed using the {@link CallService}s.
* @param callServiceIds The IDs of the {@link CallService}s to organize for the call.
*
* @return A list of prioritized {@link CallService} IDs to use to complete the given call.
*/
- protected abstract List<String> select(CallInfo callInfo, List<String> callServiceIds);
+ protected abstract List<CallServiceInfo> select(
+ CallInfo callInfo, List<CallServiceInfo> callServiceInfos);
}
@@ -91,9 +91,10 @@ public abstract class CallServiceSelector extends Service {
*
* @param callInfo The call being placed using the {@link CallService}s.
- * @param callServiceIds The IDs of the {@link CallService}s to organize for the call.
- *
- * @return A list of prioritized {@link CallService} IDs to use to complete the given call.
+ * @param callServiceInfos The details of the available {@link CallService}s with which to place
+ * the call.
+ * @return A list of prioritized {@link CallServiceInfo}s to use to complete the given call.
*/